<?php
$translations = array(
	'General_Locale' => 'nb_NO.UTF-8',
	'General_TranslatorName' => 'Hans Fredrik Nordhaug',
	'General_TranslatorEmail' => 'hans@nordhaug.priv.no',
	'General_EnglishLanguageName' => 'Norwegian Bokmål',
	'General_OriginalLanguageName' => 'Norsk (bokmål)',
	'General_HelloUser' => 'Hallo, %s!',
	'General_OpenSourceWebAnalytics' => 'Åpen kildekode nettstatistikk',
	'General_Dashboard' => 'Kontrollpanel',
	'General_DashboardForASpecificWebsite' => 'Kontrollpanel en gitt nettsted',
	'General_MultiSitesSummary' => 'Alle nettsteder',
	'General_AllWebsitesDashboard' => 'Kontrollpanel for alle nettsteder',
	'General_API' => 'API',
	'General_Widgets' => 'Element',
	'General_Settings' => 'Innstillinger',
	'General_GiveUsYourFeedback' => 'Gi oss tilbakemeldinger!',
	'General_Unknown' => 'Ukjent',
	'General_Never' => 'Aldri',
	'General_Required' => '%s påkrevd',
	'General_NotValid' => '%s er ikke gyldig',
	'General_Id' => 'Id',
	'General_Error' => 'Feil',
	'General_Warning' => 'Advarsel',
	'General_BackToHomepage' => 'Tilbake til Piwik startside',
	'General_Yes' => 'Ja',
	'General_No' => 'Nei',
	'General_Delete' => 'Slett',
	'General_Report' => 'Rapport',
	'General_Edit' => 'Endre',
	'General_Download' => 'Last ned',
	'General_Upload' => 'Last opp',
	'General_Ok' => 'Ok',
	'General_Close' => 'Lukk',
	'General_Cancel' => 'Avbryt',
	'General_OrCancel' => 'eller %s avbryt %s',
	'General_Logout' => 'Logg ut',
	'General_Username' => 'Brukernavn',
	'General_Description' => 'Beskrivelse',
	'General_Done' => 'Ferdig',
	'General_Name' => 'Navn',
	'General_Value' => 'Verdi',
	'General_Details' => 'Detaljer',
	'General_Default' => 'Standard',
	'General_Visit' => 'Besøk',
	'General_VisitorIP' => 'IP for besøkende',
	'General_VisitType' => 'Type besøkende',
	'General_DaysSinceLastVisit' => 'Dager siden siste besøk',
	'General_DaysSinceFirstVisit' => 'Dager siden første besøk',
	'General_NumberOfVisits' => 'Antall besøk',
	'General_NewVisitor' => 'Ny besøk',
	'General_ReturningVisitor' => 'Tilbakevendende besøkende',
	'General_Date' => 'Dato',
	'General_Period' => 'Periode',
	'General_ChooseDate' => 'Velg dato',
	'General_Today' => 'I dag',
	'General_Yesterday' => 'I går',
	'General_CurrentWeek' => 'Gjeldende uke',
	'General_CurrentMonth' => 'Gjeldende måned',
	'General_CurrentYear' => 'Gjeldende år',
	'General_DateRange' => 'Datointervall:',
	'General_DateRangeInPeriodList' => 'Datointervall',
	'General_ApplyDateRange' => 'Bruk datointervall',
	'General_InvalidDateRange_js' => 'Ugyldig datointervall, prøv igjen',
	'General_DateRangeFrom_js' => 'Fra',
	'General_DateRangeTo_js' => 'Til',
	'General_PreviousDays' => 'Tidligere %s dager (ikke inkludert i dag)',
	'General_LastDays' => 'Siste %s dager (inkludert i dag)',
	'General_LoadingData' => 'Laster data ...',
	'General_Loading_js' => 'Laster ...',
	'General_GoTo' => 'Gå til %s',
	'General_Next' => 'Neste',
	'General_Previous' => 'Forrige',
	'General_Search' => 'Søk',
	'General_Others' => 'Andre',
	'General_Table' => 'Tabell',
	'General_Piechart' => 'Kakediagram',
	'General_TagCloud' => 'Merkelappsky',
	'General_VBarGraph' => 'Søylediagram',
	'General_OpenInNewWindow_js' => 'Åpne i nytt vindu',
	'General_SaveImageOnYourComputer_js' => 'For å lagre bildet på din datamaskin, høyreklikk på bildet og velg "Lagre bilde som ..."',
	'General_Refresh' => 'Last siden på nytt',
	'General_Visitors' => 'Besøkende',
	'General_ExportThisReport' => 'Eksporter dette datasett i andre format',
	'General_ExportAsImage_js' => 'Eksporter som bilde',
	'General_Export' => 'Eksporter',
	'General_YourChangesHaveBeenSaved' => 'Din endringer er lagret.',
	'General_ErrorRequest' => 'Oops… problem oppstod under forespørsel, prøv igjen.',
	'General_ColumnNbUniqVisitors' => 'Unike besøkende',
	'General_ColumnNbVisits' => 'Besøk',
	'General_ColumnPercentageVisits' => '% besøk',
	'General_ColumnNbActions' => 'Handlinger',
	'General_NbActions' => 'Antall handlinger',
	'General_ColumnMaxActions' => 'Maksimalt antall handlinger under ett besøk',
	'General_ColumnSumVisitLength' => 'Total tid brukt av besøkende (i sekunder)',
	'General_ColumnLabel' => 'Type',
	'General_ColumnConversionRate' => 'Konvertingsrate',
	'General_ColumnActionsPerVisit' => 'Handlinger pr besøk',
	'General_VisitDuration' => 'Gj. besøksvarighet (i sekunder)',
	'General_ColumnAvgTimeOnSite' => 'Gj. tid på nettstedet',
	'General_ColumnVisitDuration' => 'Besøksvarighet (i sekunder)',
	'General_ColumnBounceRate' => 'Sprettfrekvens',
	'General_ColumnExitRate' => 'Utgangsfrekvens',
	'General_ColumnPageviews' => 'Sidevisninger',
	'General_ColumnUniquePageviews' => 'Unike sidevisninger',
	'General_ColumnBounces' => 'Sprett',
	'General_ColumnEntrances' => 'Innganger',
	'General_ColumnExits' => 'Utganger',
	'General_ColumnAverageTimeOnPage' => 'Gj. tid på side',
	'General_ColumnValuePerVisit' => 'Verdi per besøk',
	'General_ColumnVisitsWithConversions' => 'Besøk med konvertering',
	'General_YearsDays' => '%1$s år %2$s dager',
	'General_DaysHours' => '%1$s dager %2$s timer',
	'General_HoursMinutes' => '%1$s timer %2$s min',
	'General_MinutesSeconds' => '%1$s min %2$ss',
	'General_Seconds' => '%ss',
	'General_Save' => 'Lagre',
	'General_ForExampleShort' => 'f.eks.',
	'General_YouMustBeLoggedIn' => 'Du må være innlogget for å bruke denne funksjonaliteten.',
	'General_Website' => 'Nettsted',
	'General_GeneralSettings' => 'Generelle innstillinger',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Tillatt at Piwik-arkivering utløses når rapporter vises i nettleseren',
	'General_ArchivingTriggerDescription' => 'For større Piwik-installasjoner anbefales det at du setter opp en %scron-jobb%s for å behandle rapporter automatisk.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Se %sden offisielle dokumentasjonen%s for mer informasjon.',
	'General_NSeconds' => '%s sekund',
	'General_RequiresFlash' => 'Visning av grafikk i Piwik krever Flash',
	'General_GraphHelp' => 'Mer informasjon om visning av grafikk i Piwik',
	'General_NoDataForTagCloud' => 'Ingen data for denne merkelappskyen.',
	'General_DisplaySimpleTable' => 'Vis enkel tabell',
	'General_DisplayTableWithMoreMetrics' => 'Vis en tabell mer flere måltall',
	'General_YouAreViewingDemoShortMessage' => 'Du ser for øyeblikket på Piwik-demoen',
	'General_DownloadFullVersion' => '%1$sLast ned%2$s den fullstendige utgaven! Prøv %3$s',
	'General_NewUpdatePiwikX' => 'Ny utgave: Piwik %s',
	'General_AboutPiwikX' => 'Om Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s er tilgjengelig. %2$s Oppdater nå!%3$s (se %4$s endringer%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s er tilgjengelig. Gjør nettstedets administrator oppmerksom på dette.',
	'General_BackToPiwik' => 'Tilbake til Piwik',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'Mai',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Aug',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Okt',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Des',
	'General_LongMonth_1' => 'Januar',
	'General_LongMonth_2' => 'Februar',
	'General_LongMonth_3' => 'Mars',
	'General_LongMonth_4' => 'April',
	'General_LongMonth_5' => 'Mai',
	'General_LongMonth_6' => 'Juni',
	'General_LongMonth_7' => 'Juli',
	'General_LongMonth_8' => 'August',
	'General_LongMonth_9' => 'September',
	'General_LongMonth_10' => 'Oktober',
	'General_LongMonth_11' => 'November',
	'General_LongMonth_12' => 'Desember',
	'General_ShortDay_1' => 'Man',
	'General_ShortDay_2' => 'Tir',
	'General_ShortDay_3' => 'Ons',
	'General_ShortDay_4' => 'Tor',
	'General_ShortDay_5' => 'Fre',
	'General_ShortDay_6' => 'Lør',
	'General_ShortDay_7' => 'Søn',
	'General_LongDay_1' => 'Mandag',
	'General_LongDay_2' => 'Tirsdag',
	'General_LongDay_3' => 'Onsdag',
	'General_LongDay_4' => 'Torsdag',
	'General_LongDay_5' => 'Fredag',
	'General_LongDay_6' => 'Lørdag',
	'General_LongDay_7' => 'Søndag',
	'General_Daily' => 'Daglig',
	'General_Weekly' => 'Ukentlig',
	'General_Monthly' => 'Månedlig',
	'General_ConfigFileIsNotWritable' => 'Konfigurasjonsfilen for Piwik %s er ikke skrivbar. Noen av endringene dine blir kanskje ikke lagret. %s Endre rettighetene for filen slik at den er skrivbar.',
	'General_ExceptionDatabaseVersion' => 'Din %1$s versjon er %2$s, men Piwik krever minst %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Din %1$s klientversjon er %2$s som ikke passer med tjenerversjonen %3$s.',
	'General_ExceptionMissingFile' => 'Mangler fil: %s',
	'General_ExceptionFilesizeMismatch' => 'Filstørrelse stemmer ikke: %1$s (forventet lengde: %2$s, fant: %3$s)',
	'General_ExceptionFileIntegrity' => 'Integritetssjekk feilet: %s',
	'General_PleaseSpecifyValue' => 'Oppgi en verdi for «%s».',
	'General_ExceptionInvalidPeriod' => 'Perioden «%s» er ikke støttet. Prøv en av følgende istedenfor: %s',
	'General_ExceptionInvalidDateRange' => 'Datoen «%s» er ikke et gyldig datointervall. Riktig format er: %s',
	'General_ExceptionUndeletableFile' => 'Klarte ikke slette %s',
	'General_ExceptionConfigurationFileNotFound' => 'Klarte ikke finne konfigurasjonsfila {%s}.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Klarte ikke lese konfigurasjonsfila {%s}. Verten din kan ha deaktivert %s.',
	'General_ExceptionInvalidDateFormat' => 'Datoformatet må være %s eller et nøkkelord støttet av %s-funksjonen (se %s for mer informasjon).',
	'General_ExceptionLanguageFileNotFound' => 'Fant ikke språkfila «%s».',
	'General_WarningFileIntegritySkipped' => 'Utviklingsmiljø oppdaget. Hoppet over integritetskontroll.',
	'General_WarningFileIntegrityNoManifest' => 'Klarte ikke utføre integritetskontroll av filer fordi manifest.inc.php mangler.',
	'General_WarningFileIntegrityNoMd5file' => 'Klarte ikke utføre integritetskontroll av filer fordi funksjonen md5_file mangler.',
	'General_FileIntegrityWarningExplanation' => 'Integritetskontrollen av filer oppdaget noen feil. Dette skyldes mest sannsynlig feil under opplasting av Piwik sine filer. Du bør laste opp alle Piwik sine filer på nytt i BINARY-modus og oppfriske siden inntil ingen feil vises.',
	'General_UseSMTPServerForEmail' => 'Bruk SMTP-tjener for e-post',
	'General_SmtpServerAddress' => 'SMTP-tjeneradresse',
	'General_SmtpPort' => 'SMTP-port',
	'General_AuthenticationMethodSmtp' => 'Autentiseringsmetode for SMTP',
	'General_SmtpUsername' => 'SMTP-brukernavn',
	'General_SmtpPassword' => 'SMTP-passord',
	'General_SmtpEncryption' => 'SMTP-kryptering',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Velg «Ja» hvis du vil sende e-post med en navngitt tjener istedenfor den lokale mail-funksjonen',
	'General_OnlyEnterIfRequired' => 'Skriv bare inn et brukernavn hvis din SMTP-tjener krever det',
	'General_OnlyEnterIfRequiredPassword' => 'Skriv bare inn et passord hvis din SMTP-tjener krever det',
	'General_WarningPasswordStored' => '%sAdvarsel:%s Dette passordet lagres i klartekst i konfigurasjonsfilen slik at alle med tilgang kan lese det.',
	'General_InvalidResponse' => 'De mottatte dataene er ugyldige.',
	'General_ChooseLanguage' => 'Velg språk',
	'General_ChoosePeriod' => 'Velg periode',
	'General_ChooseWebsite' => 'Velg nettsted',
	'General_Language' => 'Språk',
	'General_PleaseUpdatePiwik' => 'Oppdatering din Piwik',
	'General_RequestTimedOut' => 'En dataforespørsel til %s fikk tidsavbrudd. Prøv igjen.',
	'Actions_PluginDescription' => 'Rapporterer om sidevisinger, utlenker og nedlastinger. Sporing av utlenker og nedlastinger skjer automatisk.',
	'Actions_Actions' => 'Handlinger',
	'Actions_SubmenuPages' => 'Sider',
	'Actions_SubmenuPagesEntry' => 'Innganssider',
	'Actions_SubmenuPagesExit' => 'Utgangssider',
	'Actions_WidgetExitPageTitles' => 'Utgangs Side Tittler',
	'Actions_SubmenuPageTitles' => 'Sidetitler',
	'Actions_WidgetPageTitles' => 'Side Tittler',
	'Actions_WidgetPageTitlesFollowingSearch' => 'Side Tittel fulgt av ett sidesøk',
	'Actions_SubmenuOutlinks' => 'Utlenker',
	'Actions_SubmenuDownloads' => 'Nedlastinger',
	'Actions_SubmenuSitesearch' => 'Sidesøk',
	'Actions_ColumnClicks' => 'Klikk',
	'Actions_ColumnClicksDocumentation' => 'Antall klikk på denne lenken',
	'Actions_ColumnUniqueClicks' => 'Unike klikk',
	'Actions_ColumnDownloads' => 'Nedlastinger',
	'Actions_ColumnUniqueDownloads' => 'Unike nedlastinger',
	'Actions_ColumnOutlinks' => 'Utlenker',
	'Actions_ColumnUniqueOutlinks' => 'Unike utlenker',
	'Actions_ColumnPageName' => 'Sidenavn',
	'Actions_ColumnPageURL' => 'URL for side',
	'Actions_ColumnSearchCategory' => 'Søkekategori',
	'Actions_ColumnSearchResultsCount' => 'Antall Søke Resultater',
	'Actions_ColumnSearchKeyword' => 'Nøkkelord',
	'Actions_ColumnClickedURL' => 'URL for klikk',
	'Actions_ColumnDownloadURL' => 'URL for nedlasting',
	'Actions_ColumnEntryPageURL' => 'URL for inngangsside',
	'Actions_ColumnEntryPageTitle' => 'Tittel for inngangsside',
	'Actions_ColumnExitPageURL' => 'URL for utgangsside',
	'Actions_ColumnExitPageTitle' => 'Tittel for utgangsside',
	'Actions_ColumnNoResultKeyword' => 'Nøkkelord uten søkeresultat',
	'Actions_ColumnSearches' => 'Søk',
	'Actions_ColumnSiteSearchKeywords' => 'Unike nøkkelord',
	'Actions_ColumnSearchesDocumentation' => 'Antall besøkende som søkte etter dette nøkkelordet i din søkemotor.',
	'Actions_ColumnSearchExits' => '% Søk Eksisterer',
	'Actions_ColumnSearchExitsDocumentation' => 'Antall besøkende som forlot webside etter og ha søkt etter dette nøkkelordet.',
	'Actions_ColumnPagesPerSearch' => 'Søke Resultater',
	'Actions_AvgGenerationTimeTooltip' => 'Gjennomsnitt basert på %s treff %s mellom %s og %s',
	'API_LoadedAPIs' => 'Lastet %s API',
	'CoreAdminHome_PluginDescription' => 'Administrasjonsområdet for Piwik.',
	'CoreAdminHome_MenuGeneralSettings' => 'Generelle innstillinger',
	'CoreAdminHome_MenuManage' => 'Administrer',
	'CoreAdminHome_Administration' => 'Administrasjon',
	'CoreAdminHome_EmailServerSettings' => 'Innstillinger for e-posttjener',
	'CoreAdminHome_OptOutForYourVisitors' => 'Piwik «opt-out» for dine besøkende',
	'CoreAdminHome_YouMayOptOut' => 'Du kan velge å ikke få tildelt en unik id for nettanalyse slik at du ikke blir en del av analysegrunnlaget',
	'CoreAdminHome_YouMayOptOutBis' => 'Hvis du ikke ønsker å delta, klikk under for å motta en blank informasjonskapsel så du ikke registreres.',
	'CoreAdminHome_YouAreOptedIn' => 'Du deltar i analysegrunnlaget',
	'CoreAdminHome_YouAreOptedOut' => 'Du deltar ikke i analysegrunnlaget',
	'CoreAdminHome_ClickHereToOptOut' => 'Trykk her for å ikke delta.',
	'CoreAdminHome_ClickHereToOptIn' => 'Trykk her for å delta.',
	'CoreAdminHome_ImageTracking' => 'Bilde sporing',
	'CoreAdminHome_ImageTrackingLink' => 'Sporings lenke for bilde',
	'CoreAdminHome_ForBetaTestersOnly' => 'Kun for beta testere',
	'CoreHome_PluginDescription' => 'Struktur for nettstatistikkrapporter.',
	'CoreHome_WebAnalyticsReports' => 'Nettstatistikkrapporter',
	'CoreHome_JavascriptDisabled' => 'JavaScript må være aktivert for at du skal kunne bruke Piwik i standardvisning.<br />Det ser ut til at JavaScript enten er deaktivert eller ikke støttet av din nettleser.<br />For å bruke standardvisning, må du aktivere JavaScript i nettleserinnstillingene og deretter %1$sprøve igjen%2$s.<br />',
	'CoreHome_ThereIsNoDataForThisReport' => 'Det fins ingen data for denne rapporten.',
	'CoreHome_CategoryNoData' => 'Ingen data i denne kategorien. Prøv å velge "Inkluder hele populasjon".',
	'CoreHome_ShowJSCode' => 'Vis JavaScript-koden til å sette inn på din nettside.',
	'CoreHome_PageOf_js' => '%1$s av %2$s',
	'CoreHome_PeriodDay' => 'Dag',
	'CoreHome_PeriodWeek' => 'Uke',
	'CoreHome_PeriodMonth' => 'Måned',
	'CoreHome_PeriodYear' => 'År',
	'CoreHome_PeriodDays' => 'dager',
	'CoreHome_PeriodWeeks' => 'uker',
	'CoreHome_PeriodMonths' => 'måneder',
	'CoreHome_PeriodYears' => 'år',
	'General_DaySu_js' => 'Sø',
	'General_DayMo_js' => 'Ma',
	'General_DayTu_js' => 'Ti',
	'General_DayWe_js' => 'On',
	'General_DayTh_js' => 'To',
	'General_DayFr_js' => 'Fr',
	'General_DaySa_js' => 'Lø',
	'General_ShortDay_1_js' => 'Søn',
	'General_ShortDay_2_js' => 'Man',
	'General_ShortDay_3_js' => 'Tir',
	'General_ShortDay_4_js' => 'Ons',
	'General_ShortDay_5_js' => 'Tor',
	'General_ShortDay_6_js' => 'Fre',
	'General_ShortDay_7_js' => 'Lør',
	'General_LongDay_1_js' => 'Søndag',
	'General_LongDay_2_js' => 'Mandag',
	'General_LongDay_3_js' => 'Tirsdag',
	'General_LongDay_4_js' => 'Onsdag',
	'General_LongDay_5_js' => 'Torsdag',
	'General_LongDay_6_js' => 'Fredag',
	'General_LongDay_7_js' => 'Lørdag',
	'General_ShortMonth_1_js' => 'Jan',
	'General_ShortMonth_2_js' => 'Feb',
	'General_ShortMonth_3_js' => 'Mar',
	'General_ShortMonth_4_js' => 'Apr',
	'General_ShortMonth_5_js' => 'Mai',
	'General_ShortMonth_6_js' => 'Jun',
	'General_ShortMonth_7_js' => 'Jul',
	'General_ShortMonth_8_js' => 'Aug',
	'General_ShortMonth_9_js' => 'Sep',
	'General_ShortMonth_10_js' => 'Okt',
	'General_ShortMonth_11_js' => 'Nov',
	'General_ShortMonth_12_js' => 'Dec',
	'General_MonthJanuary_js' => 'Januar',
	'General_MonthFebruary_js' => 'Februar',
	'General_MonthMarch_js' => 'Mars',
	'General_MonthApril_js' => 'April',
	'General_MonthMay_js' => 'Mai',
	'General_MonthJune_js' => 'Juni',
	'General_MonthJuly_js' => 'Juli',
	'General_MonthAugust_js' => 'August',
	'General_MonthSeptember_js' => 'September',
	'General_MonthOctober_js' => 'Oktober',
	'General_MonthNovember_js' => 'November',
	'General_MonthDecember_js' => 'Desember',
	'CorePluginsAdmin_PluginDescription' => 'Grensesnitt for administrasjon av tillegg',
	'CorePluginsAdmin_Plugins' => 'Tillegg',
	'CorePluginsAdmin_PluginsManagement' => 'Administrasjon av tillegg',
	'CorePluginsAdmin_MainDescription' => 'Tillegg kan utvide eller begrense funksjonaliteten i Piwik. Når et tillegg har blitt installert, kan du slå det av eller på her.',
	'CorePluginsAdmin_Plugin' => 'Tillegg',
	'CorePluginsAdmin_Version' => 'Versjon',
	'CorePluginsAdmin_Status' => 'Status',
	'CorePluginsAdmin_Action' => 'Handling',
	'CorePluginsAdmin_PluginHomepage' => 'Hjemmeside for tillegg',
	'CorePluginsAdmin_Activated' => 'Påslått',
	'CorePluginsAdmin_Active' => 'På',
	'CorePluginsAdmin_Inactive' => 'Av',
	'CorePluginsAdmin_Deactivate' => 'Slå av',
	'CorePluginsAdmin_Activate' => 'Slå på',
	'CorePluginsAdmin_MenuPlugins' => 'Tillegg',
	'CoreUpdater_PluginDescription' => 'Piwik-oppdateringsmekanisme',
	'CoreUpdater_UpdateTitle' => 'Oppdater',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Databaseoppgradering er nødvendig',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik-databasen din er utdatert og må oppgraderes før du kan fortsette.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik-databasen blir oppgradert fra versjon %1$s til versjon %2$s .',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Følgende tillegg vil nå bli oppdatert: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Viktig merknad for store Piwik-installasjoner',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Hvis du har en stor Piwik-database, kan oppdateringer ta for lang tid til at de kan kjøres i nettleseren. I slike situasjoner kan du utføre oppdateringene fra kommandolinja: %s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => 'Hvis du ikke kan oppdatere fra kommandolinja og hvis Piwik ikke klarer å oppdatere (på grunn av tidsavbrudd i databasen eller nettleseren, eller en annen grunn), så kan du utføre SQL-spørringene manuelt.',
	'CoreUpdater_ClickHereToViewSqlQueries' => 'Klikk her for å se og kopiere listen med SQL-spørringer som vil bli utført.',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => 'Merk: Hvis du utfører disse spørringene manuelt, så er det forventet at noen av dem feiler. Hvis det skjer, så skal du bare ignorere det og fortsette med neste spørringen på lista.',
	'CoreUpdater_ReadyToGo' => 'Klar til å starte?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Databaseoppgraderingen kan ta en stund, vennligst vær litt tålmodig.',
	'CoreUpdater_UpgradePiwik' => 'Oppgrader Piwik',
	'CoreUpdater_ErrorDIYHelp' => 'Hvis du er en avansert bruker og oppdager en feil i databaseoppgraderingen:',
	'CoreUpdater_ErrorDIYHelp_1' => 'identifiser og fiks kilden til problemet (f.eks. memory_limit eller max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'kjør de gjenstående forespørslene i oppdateringen som feilet',
	'CoreUpdater_ErrorDIYHelp_3' => 'manuelt oppdater "option"-tabellen i din Piwik-database; sett verdien av version_core til versjonen for den oppdateringen som feilet',
	'CoreUpdater_ErrorDIYHelp_4' => 'start oppdateringen på nytt (enten i nettleseren eller på kommandolinja) for å fortsette med de gjenstående oppdateringene',
	'CoreUpdater_ErrorDIYHelp_5' => 'rapporter problemet (og løsningen) slik at Piwik kan bli forbedret',
	'CoreUpdater_HelpMessageContent' => 'Sjekk %s Piwik FAQ-en %s som prøver å forklare de mest vanlige feil under oppdatering. %s Spør din systemadministrator - vedkommende kan kanskje hjelpe deg med feilen som antakelig har sammenheng med din tjener eller MySQL-installasjon.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritisk feil under oppdateringen:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Over vises feilmeldingen. Den bør hjelpe deg med å forklare årsaken, men hvis du trenger mer hjelp, vennligst:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Oppdateringen er fullført, men det var noen småproblemer under prossessen. Les beskrivelsene over for mer informasjon. For videre hjelp:',
	'CoreUpdater_UpgradeComplete' => 'Oppgradering fullført!',
	'CoreUpdater_WarningMessages' => 'Advarsler:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Feil under oppdatering av tillegg:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Følgende tillegg ble (automatisk) slått av: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik ble korrekt oppdatert!',
	'CoreUpdater_ContinueToPiwik' => 'Fortsett til Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Oppdater automatisk',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Du kan oppdatere til en ny versjon av Piwik.',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Du kan oppdatere til versjon %s automatisk eller laste ned pakken og installere manuelt.',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik klarte ikke skrive over din nåværende installasjon. Du kan enten fikse mappe/filrettighetene eller laste ned pakken og installere versjon %s manuelt:',
	'CoreUpdater_DownloadX' => 'Last ned %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Den automatiske oppdateringen av Piwik har blitt avbrutt. Hvis du ikke kan fikse feilen over, anbefales det at du oppdaterer Piwik manuelt. %s Les  %soppdateringsdokumentasjonen%s for å komme i gang!',
	'CoreUpdater_DownloadingUpdateFromX' => 'Laster ned oppdatering fra %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Pakker ut oppdateringen',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Verifiserer de utpakkede filene',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Oppretter en sikkerhetskopi av konfigurasjonsfilene i %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Installerer siste versjon.',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik ble vellykket oppdatert!',
	'CoreUpdater_EmptyDatabaseError' => 'Databasen %s er tom. Du må enten redigere eller fjerne din Piwik konfigurasjonsfil.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Din Piwik versjon %s er siste utgave.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Inkompatibelt arkiv: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Tomt arkiv.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arkivet er ikke komplett - noen file mangler (f.eks. %s).',
	'CustomVariables_PluginDescription' => 'Egendefinerte variabler er navn og verdier som du kan sette for en besøkende via funksjonen setVisitCustomVariables() i Javascript API-et. Piwik vil da kunne rapportere hvor mange besøkende, sider, konverteringer som benytter disse egendefinerte variablene og verdiene.',
	'CustomVariables_CustomVariables' => 'Egendefinerte variabler',
	'CustomVariables_TrackingHelp' => 'Hjelp: %1$sSporing av egendefinerte variabler i Piwik%2$s',
	'Dashboard_PluginDescription' => 'Ditt nettanalyse-kontrollpanel. Du kan tilpasse kontrollpanelet: Legge til nye element, endre rekkefølgene for dine element. Hver bruker kan tilpasse sitt eget kontrollpanel.',
	'Dashboard_Dashboard' => 'Kontrollpanel',
	'Dashboard_DeleteWidgetConfirm' => 'Er du sikker på at du vil fjerne dette elementet fra ditt kontrollpanel?',
	'Dashboard_SelectWidget' => 'Velg hvilket element som du vil legge til kontrollpanelet.',
	'Dashboard_AddPreviewedWidget_js' => 'Legg til forhåndsvist element til kontrollpanelet.',
	'Dashboard_WidgetPreview_js' => 'Forhåndsvisning av element',
	'Dashboard_Close_js' => 'Lukk',
	'Dashboard_TitleWidgetInDashboard_js' => 'Elementet er allerede i kontrollpanelet',
	'Dashboard_TitleClickToAdd_js' => 'Klikk her for å legge til kontrollpanelet',
	'Dashboard_LoadingWidget_js' => 'Laster element, vennligst vent ...',
	'Dashboard_WidgetNotFound_js' => 'Finner ikke element',
	'Dashboard_ResetDashboard' => 'Nullstill kontrollpanel',
	'Dashboard_ChangeDashboardLayout' => 'Endre layout for kontrollpanel',
	'Dashboard_DashboardOf' => 'Kontrollpanel for %s',
	'Dashboard_ManageDashboard' => 'Administrer kontrollpanel',
	'Dashboard_CreateNewDashboard' => 'Opprett nytt kontrollpanel',
	'Dashboard_RenameDashboard' => 'Gi nytt navn på kontrollpanel',
	'DBStats_PluginDescription' => 'Dette tillegget rapporterer MySQL-databasebruk for Piwik-tabeller.',
	'DBStats_DatabaseUsage' => 'Databasebruk',
	'DBStats_MainDescription' => 'Piwik lagrer all din statistikk i MySQL-databasen. Akkurat nå bruker Piwik-tabellene %s.',
	'DBStats_LearnMore' => 'For å lære mer om hvordan Piwik behandler data og hvordan få Piwik til å virke bra for nettsteder med medium og høy trafikk, les dokumentasjonen %s.',
	'DBStats_Table' => 'Tabell',
	'DBStats_RowCount' => 'Antall rader',
	'DBStats_DataSize' => 'Datastørrelse',
	'DBStats_IndexSize' => 'Indeksstørrelse',
	'DBStats_TotalSize' => 'Total størrelse',
	'Feedback_PluginDescription' => 'Send din tilbakemelding til Piwik-laget. Del din ideer og forslag med oss!',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Har du en feil å rapportere eller ny funksjonalitet du ønsker deg?',
	'Feedback_ViewAnswersToFAQ' => 'Se svar på %s ofte stilte spørsmål%s.',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Hvorfor spores ikke besøk på mitt nettsted?',
	'Feedback_HowToExclude' => 'Hvordan ekskluderer jeg sporing av mine besøk?',
	'Feedback_WhyWrongCountry' => 'Hvorfor viser Piwik mine besøk fra feil land?',
	'Feedback_HowToAnonymizeIP' => 'Hvordan maskerer jeg besøkendes IP-adresser i min database?',
	'Feedback_VisitTheForums' => 'Besøk %sforumet%s',
	'Feedback_LearnWaysToParticipate' => 'Lær om alle måtene du kan %s bidra%s',
	'Feedback_SpecialRequest' => 'Har du en spesiell forespørsel til Piwik-laget?',
	'Feedback_ContactThePiwikTeam' => 'Kontakt Piwik-laget!',
	'Feedback_IWantTo' => 'Jeg vil:',
	'Feedback_CategoryShareStory' => 'Dele en Piwik-suksesshistorie',
	'Feedback_CategorySponsor' => 'Sponse Piwik',
	'Feedback_CategoryHire' => 'Leie inn en Piwik-konsulent',
	'Feedback_CategorySecurity' => 'Rapportere et sikkerhetsproblem',
	'Feedback_MyEmailAddress' => 'Min e-postadresse:',
	'Feedback_MyMessage' => 'Min melding:',
	'Feedback_DetailsPlease' => '(inkluder alle detaljer)',
	'Feedback_SendFeedback' => 'Send tilbakemelding',
	'Feedback_ManuallySendEmailTo' => 'Send meldingen manuelt til',
	'Feedback_MessageSent' => 'Din melding ble sendt til Piwik-laget',
	'Feedback_ThankYou' => 'Takk for at du hjelper oss å lage Piwik bedre!',
	'Feedback_ThePiwikTeam' => 'Piwik-laget',
	'Feedback_ExceptionBodyLength' => 'Meldingen må være minst %s tegn lang.',
	'Feedback_ExceptionNoUrls' => 'Meldingen kan ikke inneholde en URL (for å unngå spam)',
	'Goals_Goals' => 'Mål',
	'Goals_GoalsManagement' => 'Administrasjon av mål',
	'Goals_ColumnConversions' => 'Konvertering',
	'Goals_ColumnRevenue' => 'Inntekter',
	'Goals_AddNewGoal' => 'Legg til et nytt mål',
	'Goals_AddGoal_js' => 'Legg til mål',
	'Goals_UpdateGoal_js' => 'Oppdater mål',
	'Goals_GoalName' => 'Målnavn',
	'Goals_Download' => 'Last ned en fil',
	'Goals_Pattern' => 'Mønster',
	'Installation_Installation' => 'Installasjon',
	'Installation_InstallationStatus' => 'Installasjonsstatus',
	'Installation_PercentDone' => '%s %% ferdig',
	'Installation_NoConfigFound' => 'Klarte ikke finne konfigurasjonsfilen for Piwik, og du prøver å få tilgang til en Piwik-side. <br /><b>  »Du kan <a href=\'index.php\'>installere Piwik nå</a></b><br /><small>Hvis du prøvde å installere Piwik tidligere og har noen tabeller i databasen, kan du ta det med ro. Du kan bruke de gamle tabellene og beholde dine eksisterende data!</small>',
	'Installation_DatabaseSetup' => 'Databaseinnstillinger',
	'Installation_DatabaseSetupServer' => 'databasetjener',
	'Installation_DatabaseSetupLogin' => 'brukernavn',
	'Installation_DatabaseSetupPassword' => 'passord',
	'Installation_DatabaseSetupDatabaseName' => 'databasenavn',
	'Installation_DatabaseSetupTablePrefix' => 'tabellprefiks',
	'Installation_DatabaseSetupAdapter' => 'adapter',
	'Installation_DatabaseErrorConnect' => 'Klarte ikke koble til databasetjeneren',
	'Installation_DatabaseCheck' => 'Databasesjekk',
	'Installation_DatabaseServerVersion' => 'Databasetjener-versjon',
	'Installation_DatabaseClientVersion' => 'Databaseklient-versjon',
	'Installation_DatabaseCreation' => 'Databaseopprettelse',
	'Installation_PleaseFixTheFollowingErrors' => 'Fiks følgende feil',
	'Installation_LargePiwikInstances' => 'Hjelp for store Piwik-instanser',
	'Installation_JsTag' => 'JavaScript-kode',
	'Installation_Congratulations' => 'Gratulerer',
	'Installation_CongratulationsHelp' => '<p>Gratulerer! Din Piwik installasjon er fullført.</p><p>Sørg for at JavaScript-koden er lagt inn på dine sider, og vent på dine første besøkende!</p>',
	'Installation_ContinueToPiwik' => 'Fortsett til Piwik',
	'Installation_SetupWebsite' => 'Legg til et nettsted',
	'Installation_SetupWebSiteName' => 'navn på nettsted',
	'Installation_SetupWebSiteURL' => 'URL for nettsted',
	'Installation_Timezone' => 'tidssone for nettsted',
	'Installation_SetupWebsiteError' => 'Det skjedde en feil da nettstedet ble lagt til.',
	'Installation_SetupWebsiteSetupSuccess' => 'Nettstedet %s ble opprettet.',
	'Installation_SuperUserLogin' => 'superbrukerinnlogging',
	'Installation_Password' => 'passord',
	'Installation_PasswordRepeat' => 'passord (gjenta)',
	'Installation_Email' => 'e-post',
	'Installation_SecurityNewsletter' => 'send meg e-post om viktige Piwik-oppgraderinger og sikkerhetsvarsler',
	'Installation_CommunityNewsletter' => 'send meg e-post med oppdatering fra Piwik-samfunnet (nye tillegg, nye egenskaper, osv)',
	'Installation_PasswordDoNotMatch' => 'passordene stemmer ikke overens',
	'Installation_Requirements' => 'Krav for å kjøre Piwik',
	'Installation_Optional' => 'Valgfritt',
	'Installation_Legend' => 'Forklaring',
	'Installation_Extension' => 'utvidelse',
	'Installation_SystemCheck' => 'Systemsjekk',
	'Installation_SystemCheckPhp' => 'PHP-versjon',
	'Installation_SystemCheckExtensions' => 'Andre nødvendige utvidelser',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik krever enten mysqli utvidelsen eller både PDO og pdo_mysql utvidelsene.',
	'Installation_SystemCheckSplHelp' => 'Du må konfigurere og bygge PHP på nytt med Standard PHP Library (SPL) aktivert.',
	'Installation_SystemCheckZlibHelp' => 'Du må konfigurere og bygge PHP på nytt med zlib-støtte aktivert, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => 'Du må konfigurere og bygge PHP på nytt med iconv-støtte aktivert, --with-iconv.',
	'Installation_SystemCheckWriteDirs' => 'Kataloger med skrivetilgang',
	'Installation_SystemCheckWriteDirsHelp' => 'For å fikse denne feilen på ditt Linux-system, prøv å skriv inn følgende kommando(er)',
	'Installation_SystemCheckMemoryLimit' => 'Minnegrense',
	'Installation_SystemCheckMemoryLimitHelp' => 'På et høyt trafikkert nettsted, kan arkiveringsprossessen kreve mer minne enn det som nå er tillatt.<br />Se på memory_limit i din php.ini fil hvis nødvendig.',
	'Installation_SystemCheckOpenURL' => 'Åpne URL',
	'Installation_SystemCheckOpenURLHelp' => 'Nyhetsbrev abonnement, oppdatering påminninger og en-klikk-oppdatering krever Curl-utvidelsen, "allow_url_fopen=On" eller at fsockopen() er aktivert.',
	'Installation_SystemCheckGD' => 'GD > 2.x (grafikk)',
	'Installation_SystemCheckGDHelp' => 'Mindre grafiske elementer vil ikke fungere som ønsket.',
	'Installation_SystemCheckFunctions' => 'Nødvendige funksjoner',
	'Installation_SystemCheckTimeLimitHelp' => 'På en høyt trafikkert webside, kan arkiveringsprossessen kreve mer tid enn det som nå er tillatt.<br />Se på max_execution_time i din php.ini fil hvis nødvendig.',
	'Installation_SystemCheckMailHelp' => 'Tilbakemeldinger og "Glemt passord"-meldinger kan ikke sendes uten mail().',
	'Installation_SystemCheckMbstring' => 'mbstring',
	'Installation_SystemCheckFileIntegrity' => 'Filintegritet',
	'Installation_SystemCheckError' => 'En feil oppstod - må fikses før du kan fortsette',
	'Installation_SystemCheckWarning' => 'Piwik vil virke normalt, men noen tjenester vil kanskje mangle',
	'Installation_Tables' => 'Oppretter tabellene',
	'Installation_TablesWithSameNamesFound' => 'Noen %s tabeller i databasen din %s har samme navn som de tabellene Piwik prøver å opprette',
	'Installation_TablesFound' => 'Følgende tabeller ble funnet i databasen',
	'Installation_TablesWarningHelp' => 'Enten velg å bruke de eksisterende tabellene eller velg en ren installasjon for å slette all eksisterende data i databasen.',
	'Installation_TablesReuse' => 'Bruk de eksisterende tabellene',
	'Installation_TablesDelete' => 'Slett de oppdagede tabellene',
	'Installation_TablesDeletedSuccess' => 'Eksisterende Piwik-tabeller ble vellykket slettet',
	'Installation_TablesCreatedSuccess' => 'Tabellene ble vellykket opprettet!',
	'Installation_DatabaseCreatedSuccess' => 'Databasen %s ble vellykket opprettet!',
	'Installation_GoBackAndDefinePrefix' => 'Gå tilbake og definer et prefiks for Piwik-tabellene',
	'Installation_ConfirmDeleteExistingTables' => 'Er du sikker på at du vil slette tabellene %s fra databasen din? ADVARSEL: DATA FRA DISSE TABELLENE KAN IKKE GJENOPPRETTES!',
	'Installation_Welcome' => 'Velkommen!',
	'Installation_WelcomeHelp' => '<p>Piwik er åpen kildekode nettstatistikk-programvare som gjør det enkelt å finne informasjonen du ønsker om dine besøkende.</p><p>Denne prossessen er delt opp i %s lette steg og vil ta ca 5 minutter.</p>',
	'Installation_ErrorInvalidState' => 'Feil: Det ser ut som om du prøver å hoppe over et steg i installasjonsprosessen eller informasjonskapsler (cookies) er deaktivert eller Piwik sin konfigurasjon er allerede opprettet. %1$sForsikre deg om at du har aktivert informasjonskapsler%2$s og gå tilbake %3$s til første side av installasjonen %4$s.',
	'LanguagesManager_PluginDescription' => 'Dette tillegg viser en liste med tilgjengelige språk for Piwik-grensesnittet. Språket som velges lagres i innstillingene for hver bruker.',
	'LanguagesManager_AboutPiwikTranslations' => 'Om Piwik-oversettelser',
	'Live_PluginDescription' => 'Spioner på dine besøkende, live, i sanntid!',
	'Live_LinkVisitorLog' => 'Vis detaljert logg over besøkende',
	'Live_Actions' => 'Handlinger',
	'Live_Action' => 'Handling',
	'Live_VisitorLog' => 'Logg over besøkende',
	'Live_Time' => 'Tid',
	'Live_Referrer_URL' => 'Henvisnings-URL',
	'Live_GoalType' => 'Type',
	'Live_GoalDetails' => 'Detaljer',
	'Login_LoginPasswordNotCorrect' => 'Brukernavn og passord er ikke korrekt',
	'Login_Password' => 'Passord',
	'Login_PasswordRepeat' => 'Passord (gjenta)',
	'Login_ChangePassword' => 'Endre passord',
	'Login_LoginOrEmail' => 'Brukernavn eller e-post',
	'Login_RememberMe' => 'Husk meg',
	'Login_LogIn' => 'Logg inn',
	'Login_Logout' => 'Logg ut',
	'Login_LostYourPassword' => 'Glemt passord?',
	'Login_PasswordsDoNotMatch' => 'Passordene stemmer ikke overens.',
	'Login_InvalidUsernameEmail' => 'Feil brukernavn og/eller epost-adresse.',
	'Login_ContactAdmin' => 'Mulig grunn: Din tjener har kanskje deaktivert mail()-funksjonen. <br />Kontakt din Piwik administrator.',
	'MobileMessaging_Settings_ManagePhoneNumbers' => 'Administrer telefonnummer',
	'MultiSites_Evolution' => 'Utvikling',
	'Provider_PluginDescription' => 'Rapporterer tilbyderen for de besøkende.',
	'Provider_WidgetProviders' => 'Tilbydere',
	'Provider_ColumnProvider' => 'Tilbyder',
	'Provider_SubmenuLocationsProvider' => 'Lokasjoner og tilbyder',
	'Referers_PluginDescription' => 'Rapporterer henviserdata: Søkemotorer, nøkkelord, nettsteder, kampanjesporing, direkte inngang.',
	'Referers_Referers' => 'Henvisere',
	'Referers_SearchEngines' => 'Søkemotorer',
	'Referers_Keywords' => 'Nøkkelord',
	'Referers_DirectEntry' => 'Direkte treff',
	'Referers_Websites' => 'Nettsteder',
	'Referers_Campaigns' => 'Kampanjer',
	'Referers_Evolution' => 'Utvikling over perioden',
	'Referers_Type' => 'Henvisingstype',
	'Referers_ColumnRefererType' => 'Henvisingstype',
	'Referers_ColumnSearchEngine' => 'Søkemotor',
	'Referers_ColumnWebsite' => 'Nettsted',
	'Referers_ColumnWebsitePage' => 'Nettside',
	'Referers_ColumnKeyword' => 'Nøkkel',
	'Referers_ColumnCampaign' => 'Kampanje',
	'Referers_DetailsByRefererType' => 'Detaljer etter henvisningstype',
	'Referers_TypeDirectEntries' => '%s direkte treff',
	'Referers_TypeSearchEngines' => '%s fra søkemotorer',
	'Referers_TypeWebsites' => '%s fra nettsteder',
	'Referers_TypeCampaigns' => '%s fra kampanjer',
	'Referers_Distinct' => 'Ulike henvisere etter henvisningstype',
	'Referers_DistinctSearchEngines' => 'ulike søkemotorer',
	'Referers_DistinctKeywords' => 'ulike nøkkelord',
	'Referers_DistinctCampaigns' => 'ulike kampanjer',
	'Referers_DistinctWebsites' => 'ulike nettsteder',
	'Referers_UsingNDistinctUrls' => '(bruker %s forskjellige URL-er)',
	'Referers_SubmenuOverview' => 'Oversikt',
	'Referers_SubmenuSearchEngines' => 'Søkemotorer og nøkkelord',
	'Referers_SubmenuWebsites' => 'Nettsteder',
	'Referers_SubmenuCampaigns' => 'Kampanjer',
	'Referers_WidgetKeywords' => 'Liste over nøkkelord',
	'Referers_WidgetCampaigns' => 'Liste over kampanjer',
	'Referers_WidgetExternalWebsites' => 'Liste over eksterne nettsteder',
	'Referers_WidgetSearchEngines' => 'Beste søkemotorer',
	'Referers_WidgetOverview' => 'Oversikt',
	'SecurityInfo_Security' => 'Sikkerhet',
	'SecurityInfo_SecurityInformation' => 'PHP-sikkerhetsinformasjon',
	'SecurityInfo_Test' => 'Test',
	'SecurityInfo_Result' => 'Resultat',
	'SitesManager_Sites' => 'Nettsteder',
	'SitesManager_WebsitesManagement' => 'Administrasjon av nettsteder',
	'SitesManager_MainDescription' => 'Dine analyser trenger nettsteder! Legg til, oppdater, slett websider, og vis koden som du skal legge inn på dine websider.',
	'SitesManager_JsTrackingTag' => 'JavaScript-sporingskoden',
	'SitesManager_JsTrackingTagHelp' => 'Her er JavaScript-sporingskoden som må inkluderes på alle dine sider.',
	'SitesManager_ShowTrackingTag' => 'Vis sporingskoden',
	'SitesManager_NoWebsites' => 'Du har ingen nettsteder å administrere',
	'SitesManager_AddSite' => 'Legg til et nytt nettsted',
	'SitesManager_Urls' => 'URL-er',
	'SitesManager_MenuSites' => 'Nettsteder',
	'SitesManager_DeleteConfirm_js' => 'Er du sikker på at du ønsker å slette nettstedet %s?',
	'SitesManager_ExceptionDeleteSite' => 'Det er ikke mulig å slette dette nettstedet, da det er det eneste registrerte nettstedet. Legg til et nytt nettsted, og deretter slett dette.',
	'SitesManager_ExceptionNoUrl' => 'Du må spesifisere minst en URL til nettstedet.',
	'SitesManager_ExceptionEmptyName' => 'Nettstedets navn kan ikke være tomt.',
	'SitesManager_ExceptionInvalidUrl' => 'URL-en \'%s\' er ikke en gyldig URL.',
	'SitesManager_SuperUserCan' => 'Superbrukeren kan også %s oppgi globale innstillinger%s for nye nettsteder.',
	'SitesManager_ExcludedIps' => 'Ekskluderte IP-adresser',
	'SitesManager_GlobalListExcludedIps' => 'Global liste over ekskluderte IP-adresser',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => 'IP-adressene nedenfor blir ekskludert fra sporing på alle nettsteder.',
	'SitesManager_ExcludedParameters' => 'Ekskluderte parametre',
	'SitesManager_GlobalListExcludedQueryParameters' => 'Global liste over URL-spørreparametre som skal ekskluderes',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => 'URL-spørreparametrene nedenfor blir ekskludert fra alle side URL-rapporter.',
	'SitesManager_YourCurrentIpAddressIs' => 'Din nåværende IP-adresse er %s',
	'SitesManager_SelectACity' => 'Velg en by',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Velg en by i samme tidssone som deg.',
	'SitesManager_UTCTimeIs' => 'UTC-tid er %s.',
	'SitesManager_Timezone' => 'Tidssone',
	'SitesManager_GlobalWebsitesSettings' => 'Globale nettstedinnstillinger',
	'SitesManager_DefaultTimezoneForNewWebsites' => 'Standard tidssone for nye nettsteder',
	'SitesManager_SelectDefaultTimezone' => 'Du kan velge standard tidssone for nye nettsteder.',
	'SitesManager_Currency' => 'Valuta',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => 'Valuta-symbolet vises ved siden av omsetningsmål.',
	'SitesManager_DefaultCurrencyForNewWebsites' => 'Standard valuta for nye nettsteder',
	'SitesManager_SelectDefaultCurrency' => 'Du kan velge standard valuta for nye nettsteder.',
	'TranslationsAdmin_PluginDescription' => 'Hjelp til å oversette Piwik til ditt språk.',
	'TranslationsAdmin_MenuTranslations' => 'Oversettelser',
	'TranslationsAdmin_MenuLanguages' => 'Språk',
	'TranslationsAdmin_LanguageCode' => 'Språkkode',
	'TranslationsAdmin_Plugin' => 'Tillegg',
	'TranslationsAdmin_Definition' => 'Definisjon',
	'TranslationsAdmin_DefaultString' => 'Standard (Engelsk)',
	'TranslationsAdmin_TranslationString' => 'Oversettelse (gjeldende språk: %s)',
	'TranslationsAdmin_Translations' => 'Oversettelser',
	'TranslationsAdmin_FixPermissions' => 'Vennligst fiks filsystem-rettighetene',
	'TranslationsAdmin_AddLanguage' => 'Legg til språk',
	'TranslationsAdmin_Export' => 'Eksporter språk',
	'TranslationsAdmin_Import' => 'Importer språk',
	'UserCountry_PluginDescription' => 'Rapporterer landet for de besøkende.',
	'UserCountry_Country' => 'Land',
	'UserCountry_Continent' => 'Kontinent',
	'UserCountry_DistinctCountries' => '%s bestemte land',
	'UserCountry_Location' => 'Lokasjon',
	'UserCountry_SubmenuLocations' => 'Lokasjoner',
	'UserCountry_country_ac' => 'Ascension øyene',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'De forente arabiske emirater',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua og Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'De nederlandske Antillene',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarktika',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'Amerikansk Samoa',
	'UserCountry_country_at' => 'Østerrike',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Aland øyene',
	'UserCountry_country_az' => 'Aserbaijan',
	'UserCountry_country_ba' => 'Bosnia og Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgia',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brasil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvetøya',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Hvitrussland',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
	'UserCountry_country_cd' => 'Den demokratiske republikk Kongo',
	'UserCountry_country_cf' => 'Den sentralafrikanske republikk',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'Sveits',
	'UserCountry_country_ci' => 'Elfenbenskysten',
	'UserCountry_country_ck' => 'Cookøyene',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Kina',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cp' => 'Clippertonøya',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cape Verde',
	'UserCountry_country_cx' => 'Christmas Island',
	'UserCountry_country_cy' => 'Kypros',
	'UserCountry_country_cz' => 'Tsjekkiske republikk',
	'UserCountry_country_de' => 'Tyskland',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Danmark',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Den dominikanske republikk',
	'UserCountry_country_dz' => 'Algerie',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egypt',
	'UserCountry_country_eh' => 'Vest-Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spania',
	'UserCountry_country_et' => 'Etiopia',
	'UserCountry_country_eu' => 'Den europeiske union',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falklandsøyene',
	'UserCountry_country_fm' => 'Mikronesia, Føderasjonen',
	'UserCountry_country_fo' => 'Færøyene',
	'UserCountry_country_fr' => 'Frankrike',
	'UserCountry_country_fx' => 'Metropolitan-Frankrike',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Storbritannia',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'Fransk Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Grønland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Ekvatorial-Guinea',
	'UserCountry_country_gr' => 'Hellas',
	'UserCountry_country_gs' => 'Sør-Georgia og de sørlige Sandwichøyene',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard- og McDonaldøyene',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Kroatia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Ungarn',
	'UserCountry_country_ic' => 'Kanariøyene',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Irland',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Øya Man',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'Det britiske området i Indiahavet',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iran',
	'UserCountry_country_is' => 'Island',
	'UserCountry_country_it' => 'Italia',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kirgisistan',
	'UserCountry_country_kh' => 'Kambodsja',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Saint Kitts og Nevis',
	'UserCountry_country_kp' => 'Korea, Den demokratiske folkerepublikk',
	'UserCountry_country_kr' => 'Korea, Republikken',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Caymanøyene',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Libanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Litauen',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Latvia',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Marocco',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Republikken Moldova',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshalløyene',
	'UserCountry_country_mk' => 'Makedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Northern Mariana Islands',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldivene',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'Ny-Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolkøya',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Nederland',
	'UserCountry_country_no' => 'Norge',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Den nøytrale sona',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'New Zealand',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'French Polynesia',
	'UserCountry_country_pg' => 'Papua New Guinea',
	'UserCountry_country_ph' => 'Fillipinene',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Polen',
	'UserCountry_country_pm' => 'Saint-Pierre-et-Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinske territorier',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion Island',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_ru' => 'Russland',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Salomonøyene',
	'UserCountry_country_sc' => 'Seychellene',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sverige',
	'UserCountry_country_sf' => 'Finland',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Slovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'Sao Tome og Principe',
	'UserCountry_country_su' => 'Gamle U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Den arabiske republikk Syria',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks- og Caicosøyene',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'Franske sørlige territorier',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'Øst-Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Øst-Timor',
	'UserCountry_country_tr' => 'Tyrkia',
	'UserCountry_country_tt' => 'Trinidad og Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania, Forbundsrepublikken',
	'UserCountry_country_ua' => 'Ukraina',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'England',
	'UserCountry_country_um' => 'Mindre utenforliggende øyer til USA',
	'UserCountry_country_us' => 'USA',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatikanstaten',
	'UserCountry_country_vc' => 'Saint Vincent og Grenadinene',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Jomfruøyene (Storbritannia)',
	'UserCountry_country_vi' => 'Jomfruøyene (USA)',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis og Futunaøyene',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Jugoslavia',
	'UserCountry_country_za' => 'Sør-Afrika',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_asi' => 'Asia',
	'UserCountry_continent_amn' => 'Nord-Amerika',
	'UserCountry_continent_ams' => 'Sør- og Sentral-Ameria',
	'UserCountry_continent_oce' => 'Australia',
	'UserCountryMap_map' => 'kart',
	'UserCountryMap_worldMap' => 'verdenskart',
	'UserCountryMap_toggleFullscreen' => 'Slå av/på fullskjerm',
	'UserSettings_PluginDescription' => 'Rapporterer forskjellige brukerinnstillinger: Nettleser, nettleserfamilie, operativsystem, tillegg, oppløsning, globale innstillinger.',
	'UserSettings_VisitorSettings' => 'Besøkendes innstillinger',
	'UserSettings_BrowserFamilies' => 'Nettleserfamilier',
	'UserSettings_Browsers' => 'Nettlesere',
	'UserSettings_Plugins' => 'Tillegg',
	'UserSettings_Configurations' => 'Konfigurasjon',
	'UserSettings_OperatingSystems' => 'Operativsystem',
	'UserSettings_Resolutions' => 'Oppløsninger',
	'UserSettings_WideScreen' => 'Widescreen',
	'UserSettings_ColumnBrowserFamily' => 'Nettleserfamilie',
	'UserSettings_ColumnBrowser' => 'Nettleser',
	'UserSettings_ColumnPlugin' => 'Tillegg',
	'UserSettings_ColumnConfiguration' => 'Konfigurasjon',
	'UserSettings_ColumnOperatingSystem' => 'Operativsystem',
	'UserSettings_ColumnResolution' => 'Oppløsning',
	'UserSettings_ColumnTypeOfScreen' => 'Skjermtype',
	'UserSettings_WidgetResolutions' => 'Skjermoppløsninger',
	'UserSettings_WidgetBrowsers' => 'Besøkendes nettlesere',
	'UserSettings_WidgetPlugins' => 'Liste over tillegg',
	'UserSettings_WidgetWidescreen' => 'Normal / Widescreen',
	'UserSettings_WidgetBrowserFamilies' => 'Nettlesere etter familie',
	'UserSettings_WidgetOperatingSystems' => 'Operativsystemer',
	'UserSettings_WidgetGlobalVisitors' => 'Besøkendes konfigurasjon',
	'UserSettings_SubmenuSettings' => 'Innstillinger',
	'UsersManager_PluginDescription' => 'Brukeradministrasjon i Piwik: Legg til en ny bruker, endre en eksisterende bruker, oppdatere rettighetene. Alle handlingene er også tilgjengelig gjennom API-et.',
	'UsersManager_UsersManagement' => 'Administrasjon av brukere',
	'UsersManager_UsersManagementMainDescription' => 'Opprett nye brukere eller oppdater eksisterende. Du kan sette deres rettigheter over.',
	'UsersManager_ManageAccess' => 'Administrer tilgang',
	'UsersManager_MainDescription' => 'Bestem hvilke brukere som har tilgang til Piwik på dine nettsteder. Du kan også sette rettighetene på alle dine nettsteder på en gang.',
	'UsersManager_Sites' => 'Nettsteder',
	'UsersManager_AllWebsites' => 'Alle nettsteder',
	'UsersManager_ApplyToAllWebsites' => 'Legg til alle nettsteder',
	'UsersManager_User' => 'Bruker',
	'UsersManager_PrivNone' => 'Ingen tilgang',
	'UsersManager_PrivView' => 'Vis',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => 'Er du sikker på at du vil endre \'%s\' rettigheter på alle nettstedene?',
	'UsersManager_Password' => 'Passord',
	'UsersManager_Email' => 'E-post',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'Superbruker-aliaset kan ikke endres.',
	'UsersManager_ReportToLoadByDefault' => 'Rapport som skal lastes som standard',
	'UsersManager_ReportDateToLoadByDefault' => 'Rapportdato som skal lastes som standard',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => 'Rapportdato som skal lastes som standard for anonyme brukere',
	'UsersManager_ExcludeVisitsViaCookie' => 'Ekskluder dine besøk med en informasjonskapsel',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%sDine besøk blir ignorert av Piwik på %s %s (informasjonskapselen for ekskludering fra Piwik ble funnet i din nettleser).',
	'UsersManager_YourVisitsAreNotIgnored' => '%sDine besøk blir ikke ignorert av Piwik%s (informasjonskapselen for ekskludering fra Piwik ble ikke funnet i din nettleser).',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Klikk her for å slette informasjonskapselen og la Piwik spore dine besøk.',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => 'Klikk her for å sette en informasjonskapsel som vil ekskludere dine besøk på nettsteder som spores av Piwik på %s',
	'UsersManager_Edit' => 'Endre',
	'UsersManager_AddUser' => 'Legg til ny bruker',
	'UsersManager_MenuUsers' => 'Brukere',
	'UsersManager_MenuUserSettings' => 'Brukerinnstillinger',
	'UsersManager_MenuAnonymousUserSettings' => 'Innstillinger for anonym bruker',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Brukere som ikke er logget og besøker Piwik, skal sendes til',
	'UsersManager_ChangePassword' => 'Endre passord',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Hvis du vil endre passordet, skriv inn et nytt. Hvis ikke, lar du feltet være tomt.',
	'UsersManager_TypeYourPasswordAgain' => 'Skriv inn ditt nye passord på nytt.',
	'UsersManager_TheLoginScreen' => 'Innloggingsside',
	'UsersManager_DeleteConfirm_js' => 'Er du sikker på at du vil slette brukeren %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Brukernavnet ditt kan ikke endres.',
	'UsersManager_ExceptionLoginExists' => 'Brukernavn \'%s\' eksisterer allerede.',
	'UsersManager_ExceptionEmailExists' => 'Bruker med e-post \'%s\' eksisterer allerede.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Brukernavnet må være mellom %s og %s tegn langt og inneholde kun bokstaver, tall eller tegnene \'_\', \'-\' og \'.\'.',
	'UsersManager_ExceptionInvalidEmail' => 'Epost-adressen er ikke i gyldig format.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Bruker \'%s\' eksisterer ikke og kan derfor ikke bli slettet.',
	'UsersManager_ExceptionAdminAnonymous' => 'Du kan ikke gi administrator-tilgang til \'anonymous\'-brukeren.',
	'UsersManager_ExceptionEditAnonymous' => 'Den anonyme brukeren kan ikke bli redigert eller slettet. Den blir brukt av Piwik for å definere en bruker som ikke har blitt logget inn ennå. Du kan for eksempel gjøre statistikken din offentlig ved å gi \'view\'-tilgang til \'anonymous\'-brukeren.',
	'UsersManager_ExceptionSuperUser' => 'Den forespurte brukeren er Super User og kan ikke bli undersøkt, redigert eller slettet via API-et. Du kan redigere informasjonen for Super User manuelt i Piwik sin konfigurasjonsfil.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Bruker \'%s\' eksisterer ikke.',
	'UsersManager_ExceptionAccessValues' => 'Tilgangsparameteret må minst ha en av de følgende verdier: [ %s ]',
	'VisitFrequency_PluginDescription' => 'Rapporterer forskjellig statistikk om tilbakevendende besøkende sammenlignet med førstegangs besøkende.',
	'VisitFrequency_Evolution' => 'Utvikling over perioden',
	'VisitFrequency_ColumnReturningVisits' => 'Tilbakevendende besøk',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Handlinger av tilbakevendende besøk',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => 'Gj. besøksvarighet for tilbakevendende besøk (i sekunder)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Sprettfrekvens for tilbakevendende besøk',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'Gj. handling per tilbakevendende besøk',
	'VisitFrequency_ReturnVisits' => '%s tilbakevendende besøk',
	'VisitFrequency_ReturnActions' => '%s handlinger av de tilbakevendende besøk',
	'VisitFrequency_ReturnAverageVisitDuration' => '%s gjennomsnittlig besøksvarighet for tilbakevendende besøk',
	'VisitFrequency_ReturnBounceRate' => '%s tilbakevendende besøk har sprettet (forlatt siden etter en side).',
	'VisitFrequency_WidgetOverview' => 'Frekvens-oversikt',
	'VisitFrequency_WidgetGraphReturning' => 'Graf for tilbakevendende besøk',
	'VisitFrequency_SubmenuFrequency' => 'Frekvens',
	'VisitorInterest_VisitsPerDuration' => 'Besøk pr besøksvarighet',
	'VisitorInterest_VisitsPerNbOfPages' => 'Besøk pr antall sider',
	'VisitorInterest_ColumnVisitDuration' => 'Besøksvarighet',
	'VisitorInterest_ColumnPagesPerVisit' => 'Sider pr besøk',
	'VisitorInterest_WidgetLengths' => 'Besøkslengde',
	'VisitorInterest_WidgetPages' => 'Sider pr besøk',
	'VisitorInterest_Engagement' => 'Engasjement',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s min',
	'VisitorInterest_OnePage' => '1 side',
	'VisitorInterest_NPages' => '%s sider',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$ss',
	'VisitsSummary_PluginDescription' => 'Rapporterer generell statistikk: Besøk, unike besøkende, antall handlinger, sprettfrekvens, osv.',
	'VisitsSummary_VisitsSummary' => 'Besøksammendrag',
	'VisitsSummary_NbVisits' => '%s besøk',
	'VisitsSummary_NbUniqueVisitors' => '%s unike besøkende',
	'VisitsSummary_NbActionsDescription' => '%s handlinger (sidevisninger, nedlastinger og utlenker)',
	'VisitsSummary_NbOutlinksDescription' => '%s utlenker',
	'VisitsSummary_NbUniqueOutlinksDescription' => '%s unike utlenker',
	'VisitsSummary_AverageVisitDuration' => '%s gjennomsnittlig besøksvarighet',
	'VisitsSummary_MaxNbActions' => '%s maks handlinger i ett besøk',
	'VisitsSummary_NbActionsPerVisit' => '%s handlinger per besøk',
	'VisitsSummary_NbVisitsBounced' => '%s besøk har sprettet (forlatt nettstedet etter en side)',
	'VisitsSummary_GenerateTime' => '%s sekunder for å generere denne siden',
	'VisitsSummary_GenerateQueries' => '%s spørringer kjørt',
	'VisitsSummary_WidgetLastVisits' => 'Graf over siste besøk',
	'VisitsSummary_WidgetVisits' => 'Besøksoversikt',
	'VisitsSummary_WidgetLastVisitors' => 'Grafikk over siste unike besøkende',
	'VisitsSummary_WidgetOverviewGraph' => 'Oversikt med grafikk',
	'VisitsSummary_SubmenuOverview' => 'Oversikt',
	'VisitTime_LocalTime' => 'Besøk pr lokaltid',
	'VisitTime_ServerTime' => 'Besøk pr tjenertid',
	'VisitTime_ColumnServerTime' => 'Tjenertid',
	'VisitTime_ColumnLocalTime' => 'Lokaltid',
	'VisitTime_WidgetLocalTime' => 'Besøk etter lokaltid',
	'VisitTime_WidgetServerTime' => 'Besøk etter tjenertid',
	'VisitTime_SubmenuTimes' => 'Tider',
	'VisitTime_NHour' => '%st',
	'PDFReports_ManageEmailReports' => 'Administrer e-postrapporter',
	'PDFReports_EmailReports' => 'E-postrapporter',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_EmailSchedule' => 'E-postplan',
	'PDFReports_SendReportTo' => 'Send rapport til',
	'PDFReports_SentToMe' => 'Send til meg',
	'PDFReports_WeeklyScheduleHelp' => 'Ukeplan: Rapportene blir sendt første mandag i hver uke.',
	'PDFReports_MonthlyScheduleHelp' => 'Månedsplan: Rapportene blir sendt første dag i hver måned.',
	'PDFReports_AlsoSendReportToTheseEmails' => 'Send også rapporten til disse e-postadressene (en adresse per linje):',
	'PDFReports_PiwikReports' => 'Piwik-rapporter',
	'PDFReports_EmailHello' => 'Hei,',
	'PDFReports_PleaseFindAttachedFile' => 'I den vedlagte filen finner du din %1$s rapport for %2$s.',
	'UserLanguage_Language_aa' => 'afar',
	'UserLanguage_Language_ab' => 'abkhasisk',
	'UserLanguage_Language_ae' => 'avestisk',
	'UserLanguage_Language_af' => 'afrikaans',
	'UserLanguage_Language_ak' => 'akan',
	'UserLanguage_Language_am' => 'amharisk',
	'UserLanguage_Language_an' => 'aragonsk',
	'UserLanguage_Language_ar' => 'arabisk',
	'UserLanguage_Language_as' => 'assamisk',
	'UserLanguage_Language_av' => 'avarisk',
	'UserLanguage_Language_ay' => 'aymara',
	'UserLanguage_Language_az' => 'aserbajdsjansk',
	'UserLanguage_Language_ba' => 'basjkirsk',
	'UserLanguage_Language_be' => 'hviterussisk',
	'UserLanguage_Language_bg' => 'bulgarsk',
	'UserLanguage_Language_bh' => 'bihari',
	'UserLanguage_Language_bi' => 'bislama',
	'UserLanguage_Language_bm' => 'bambara',
	'UserLanguage_Language_bn' => 'bengali',
	'UserLanguage_Language_bo' => 'tibetansk',
	'UserLanguage_Language_br' => 'bretonsk',
	'UserLanguage_Language_bs' => 'bosnisk',
	'UserLanguage_Language_ca' => 'katalansk',
	'UserLanguage_Language_ce' => 'tsjetsjensk',
	'UserLanguage_Language_ch' => 'chamorro',
	'UserLanguage_Language_co' => 'korsikansk',
	'UserLanguage_Language_cr' => 'cree',
	'UserLanguage_Language_cs' => 'tsjekkisk',
	'UserLanguage_Language_cu' => 'kirkeslavisk',
	'UserLanguage_Language_cv' => 'tsjuvansk',
	'UserLanguage_Language_cy' => 'walisisk',
	'UserLanguage_Language_da' => 'dansk',
	'UserLanguage_Language_de' => 'tysk',
	'UserLanguage_Language_dv' => 'divehi',
	'UserLanguage_Language_dz' => 'dzongkha',
	'UserLanguage_Language_ee' => 'ewe',
	'UserLanguage_Language_el' => 'gresk',
	'UserLanguage_Language_en' => 'engelsk',
	'UserLanguage_Language_eo' => 'esperanto',
	'UserLanguage_Language_es' => 'spansk',
	'UserLanguage_Language_et' => 'estisk',
	'UserLanguage_Language_eu' => 'baskisk',
	'UserLanguage_Language_fa' => 'persisk',
	'UserLanguage_Language_ff' => 'fulani',
	'UserLanguage_Language_fi' => 'finsk',
	'UserLanguage_Language_fj' => 'fijiansk',
	'UserLanguage_Language_fo' => 'færøysk',
	'UserLanguage_Language_fr' => 'fransk',
	'UserLanguage_Language_fy' => 'vestfrisisk',
	'UserLanguage_Language_ga' => 'irsk',
	'UserLanguage_Language_gd' => 'skotsk gælisk',
	'UserLanguage_Language_gl' => 'galisisk',
	'UserLanguage_Language_gn' => 'guarani',
	'UserLanguage_Language_gu' => 'gujarati',
	'UserLanguage_Language_gv' => 'manx',
	'UserLanguage_Language_ha' => 'hausa',
	'UserLanguage_Language_he' => 'hebraisk',
	'UserLanguage_Language_hi' => 'hindi',
	'UserLanguage_Language_ho' => 'hiri motu',
	'UserLanguage_Language_hr' => 'kroatisk',
	'UserLanguage_Language_ht' => 'haitisk',
	'UserLanguage_Language_hu' => 'ungarsk',
	'UserLanguage_Language_hy' => 'armensk',
	'UserLanguage_Language_hz' => 'herero',
	'UserLanguage_Language_ia' => 'interlingua',
	'UserLanguage_Language_id' => 'indonesisk',
	'UserLanguage_Language_ie' => 'interlingue',
	'UserLanguage_Language_ig' => 'ibo',
	'UserLanguage_Language_ii' => 'sichuan-yi',
	'UserLanguage_Language_ik' => 'inupiak',
	'UserLanguage_Language_io' => 'ido',
	'UserLanguage_Language_is' => 'islandsk',
	'UserLanguage_Language_it' => 'italiensk',
	'UserLanguage_Language_iu' => 'inuktitut',
	'UserLanguage_Language_ja' => 'japansk',
	'UserLanguage_Language_jv' => 'javanesisk',
	'UserLanguage_Language_ka' => 'georgisk',
	'UserLanguage_Language_kg' => 'kikongo',
	'UserLanguage_Language_ki' => 'kikuyu',
	'UserLanguage_Language_kj' => 'kuanyama',
	'UserLanguage_Language_kk' => 'kasakhisk',
	'UserLanguage_Language_kl' => 'grønlandsk',
	'UserLanguage_Language_km' => 'khmer',
	'UserLanguage_Language_kn' => 'kannada',
	'UserLanguage_Language_ko' => 'koreansk',
	'UserLanguage_Language_kr' => 'kanuri',
	'UserLanguage_Language_ks' => 'kasjmiri',
	'UserLanguage_Language_ku' => 'kurdisk',
	'UserLanguage_Language_kv' => 'komi',
	'UserLanguage_Language_kw' => 'kornisk',
	'UserLanguage_Language_ky' => 'kirgisisk',
	'UserLanguage_Language_la' => 'latin',
	'UserLanguage_Language_lb' => 'luxemburgsk',
	'UserLanguage_Language_lg' => 'ganda',
	'UserLanguage_Language_li' => 'limburgisk',
	'UserLanguage_Language_ln' => 'lingala',
	'UserLanguage_Language_lo' => 'laotisk',
	'UserLanguage_Language_lt' => 'litauisk',
	'UserLanguage_Language_lu' => 'luba-katanga',
	'UserLanguage_Language_lv' => 'latvisk',
	'UserLanguage_Language_mg' => 'madagassisk',
	'UserLanguage_Language_mh' => 'marshallesisk',
	'UserLanguage_Language_mi' => 'maori',
	'UserLanguage_Language_mk' => 'makedonsk',
	'UserLanguage_Language_ml' => 'malayalam',
	'UserLanguage_Language_mn' => 'mongolsk',
	'UserLanguage_Language_mr' => 'marathi',
	'UserLanguage_Language_ms' => 'malayisk',
	'UserLanguage_Language_mt' => 'maltesisk',
	'UserLanguage_Language_my' => 'burmesisk',
	'UserLanguage_Language_na' => 'nauru',
	'UserLanguage_Language_nb' => 'norsk bokmål',
	'UserLanguage_Language_nd' => 'nord-ndebele',
	'UserLanguage_Language_ne' => 'nepalsk',
	'UserLanguage_Language_ng' => 'ndonga',
	'UserLanguage_Language_nl' => 'nederlandsk',
	'UserLanguage_Language_nn' => 'norsk nynorsk',
	'UserLanguage_Language_no' => 'norsk',
	'UserLanguage_Language_nr' => 'sør-ndebele',
	'UserLanguage_Language_nv' => 'navajo',
	'UserLanguage_Language_ny' => 'nyanja',
	'UserLanguage_Language_oc' => 'oksitansk',
	'UserLanguage_Language_oj' => 'ojibwa',
	'UserLanguage_Language_om' => 'oromo',
	'UserLanguage_Language_or' => 'oriya',
	'UserLanguage_Language_os' => 'ossetisk',
	'UserLanguage_Language_pa' => 'panjabi',
	'UserLanguage_Language_pi' => 'pali',
	'UserLanguage_Language_pl' => 'polsk',
	'UserLanguage_Language_ps' => 'pashto',
	'UserLanguage_Language_pt' => 'portugisisk',
	'UserLanguage_Language_qu' => 'quechua',
	'UserLanguage_Language_rm' => 'retoromansk',
	'UserLanguage_Language_rn' => 'rundi',
	'UserLanguage_Language_ro' => 'rumensk',
	'UserLanguage_Language_ru' => 'russisk',
	'UserLanguage_Language_rw' => 'kinjarwanda',
	'UserLanguage_Language_sa' => 'sanskrit',
	'UserLanguage_Language_sc' => 'sardinsk',
	'UserLanguage_Language_sd' => 'sindhi',
	'UserLanguage_Language_se' => 'nordsamisk',
	'UserLanguage_Language_sg' => 'sango',
	'UserLanguage_Language_si' => 'singalesisk',
	'UserLanguage_Language_sk' => 'slovakisk',
	'UserLanguage_Language_sl' => 'slovensk',
	'UserLanguage_Language_sm' => 'samoansk',
	'UserLanguage_Language_sn' => 'shona',
	'UserLanguage_Language_so' => 'somali',
	'UserLanguage_Language_sq' => 'albansk',
	'UserLanguage_Language_sr' => 'serbisk',
	'UserLanguage_Language_ss' => 'swati',
	'UserLanguage_Language_st' => 'sør-sotho',
	'UserLanguage_Language_su' => 'sundanesisk',
	'UserLanguage_Language_sv' => 'svensk',
	'UserLanguage_Language_sw' => 'swahili',
	'UserLanguage_Language_ta' => 'tamil',
	'UserLanguage_Language_te' => 'telugu',
	'UserLanguage_Language_tg' => 'tadsjikisk',
	'UserLanguage_Language_th' => 'thai',
	'UserLanguage_Language_ti' => 'tigrinja',
	'UserLanguage_Language_tk' => 'turkmensk',
	'UserLanguage_Language_tl' => 'tagalog',
	'UserLanguage_Language_tn' => 'setswana',
	'UserLanguage_Language_to' => 'tongansk',
	'UserLanguage_Language_tr' => 'tyrkisk',
	'UserLanguage_Language_ts' => 'tsonga',
	'UserLanguage_Language_tt' => 'tatarisk',
	'UserLanguage_Language_tw' => 'twi',
	'UserLanguage_Language_ty' => 'tahitisk',
	'UserLanguage_Language_ug' => 'uigurisk',
	'UserLanguage_Language_uk' => 'ukrainsk',
	'UserLanguage_Language_ur' => 'urdu',
	'UserLanguage_Language_uz' => 'usbekisk',
	'UserLanguage_Language_ve' => 'venda',
	'UserLanguage_Language_vi' => 'vietnamesisk',
	'UserLanguage_Language_vo' => 'volapyk',
	'UserLanguage_Language_wa' => 'vallonsk',
	'UserLanguage_Language_wo' => 'wolof',
	'UserLanguage_Language_xh' => 'xhosa',
	'UserLanguage_Language_yi' => 'jiddisk',
	'UserLanguage_Language_yo' => 'joruba',
	'UserLanguage_Language_za' => 'zhuang',
	'UserLanguage_Language_zh' => 'kinesisk',
	'UserLanguage_Language_zu' => 'zulu',

	// FOR REVIEW
	'Forecast_Visitors' => 'Besøkende',
);
